{% extends 'base.html' %}
{% block header %}
    {{ form.media }}
{% endblock %}
{% block content %}
    <form method="POST">
        {% csrf_token %}
        {{ form.as_p }}
        <input type="submit" value="Submit article">
    </form>
{% endblock %}
